@@ -6,26 +6,29 @@ Type annotations for chime-sdk-media-pipelines service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_media_pipelines.literals import ArtifactsConcatenationStateType
+    from mypy_boto3_chime_sdk_media_pipelines.literals import ActiveSpeakerPositionType
 
-    data: ArtifactsConcatenationStateType = "Disabled"
+    data: ActiveSpeakerPositionType = "BottomLeft"
     ```
 """
 import sys
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
 
 
 __all__ = (
+    "ActiveSpeakerPositionType",
     "ArtifactsConcatenationStateType",
     "ArtifactsStateType",
     "AudioArtifactsConcatenationStateType",
     "AudioChannelsOptionType",
     "AudioMuxTypeType",
+    "BorderColorType",
     "CallAnalyticsLanguageCodeType",
+    "CanvasOrientationType",
     "ConcatenationSinkTypeType",
     "ConcatenationSourceTypeType",
     "ContentMuxTypeType",
@@ -33,6 +36,8 @@ __all__ = (
     "ContentShareLayoutOptionType",
     "ContentTypeType",
     "FragmentSelectorTypeType",
+    "HighlightColorType",
+    "HorizontalTilePositionType",
     "LayoutOptionType",
     "LiveConnectorMuxTypeType",
     "LiveConnectorSinkTypeType",
@@ -50,6 +55,8 @@ __all__ = (
     "RecordingFileFormatType",
     "ResolutionOptionType",
     "SentimentTypeType",
+    "TileOrderType",
+    "VerticalTilePositionType",
     "VideoMuxTypeType",
     "VocabularyFilterMethodType",
     "VoiceAnalyticsConfigurationStatusType",
@@ -60,21 +67,28 @@ __all__ = (
 )
 
 
+ActiveSpeakerPositionType = Literal["BottomLeft", "BottomRight", "TopLeft", "TopRight"]
 ArtifactsConcatenationStateType = Literal["Disabled", "Enabled"]
 ArtifactsStateType = Literal["Disabled", "Enabled"]
 AudioArtifactsConcatenationStateType = Literal["Enabled"]
 AudioChannelsOptionType = Literal["Mono", "Stereo"]
 AudioMuxTypeType = Literal["AudioOnly", "AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
+BorderColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
 CallAnalyticsLanguageCodeType = Literal[
     "de-DE", "en-AU", "en-GB", "en-US", "es-US", "fr-CA", "fr-FR", "it-IT", "pt-BR"
 ]
+CanvasOrientationType = Literal["Landscape", "Portrait"]
 ConcatenationSinkTypeType = Literal["S3Bucket"]
 ConcatenationSourceTypeType = Literal["MediaCapturePipeline"]
 ContentMuxTypeType = Literal["ContentOnly"]
 ContentRedactionOutputType = Literal["redacted", "redacted_and_unredacted"]
-ContentShareLayoutOptionType = Literal["Horizontal", "PresenterOnly", "Vertical"]
+ContentShareLayoutOptionType = Literal[
+    "ActiveSpeakerOnly", "Horizontal", "PresenterOnly", "Vertical"
+]
 ContentTypeType = Literal["PII"]
 FragmentSelectorTypeType = Literal["ProducerTimestamp", "ServerTimestamp"]
+HighlightColorType = Literal["Black", "Blue", "Green", "Red", "White", "Yellow"]
+HorizontalTilePositionType = Literal["Bottom", "Top"]
 LayoutOptionType = Literal["GridView"]
 LiveConnectorMuxTypeType = Literal["AudioWithActiveSpeakerVideo", "AudioWithCompositedVideo"]
 LiveConnectorSinkTypeType = Literal["RTMP"]
@@ -103,6 +117,8 @@ RealTimeAlertRuleTypeType = Literal["IssueDetection", "KeywordMatch", "Sentiment
 RecordingFileFormatType = Literal["Opus", "Wav"]
 ResolutionOptionType = Literal["FHD", "HD"]
 SentimentTypeType = Literal["NEGATIVE"]
+TileOrderType = Literal["JoinSequence", "SpeakerSequence"]
+VerticalTilePositionType = Literal["Left", "Right"]
 VideoMuxTypeType = Literal["VideoOnly"]
 VocabularyFilterMethodType = Literal["mask", "remove", "tag"]
 VoiceAnalyticsConfigurationStatusType = Literal["Disabled", "Enabled"]
@@ -122,6 +138,7 @@ ServiceName = Literal[
     "apigatewayv2",
     "appconfig",
     "appconfigdata",
+    "appfabric",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -169,6 +186,7 @@ ServiceName = Literal[
     "codecommit",
     "codedeploy",
     "codeguru-reviewer",
+    "codeguru-security",
     "codeguruprofiler",
     "codepipeline",
     "codestar",
@@ -224,6 +242,7 @@ ServiceName = Literal[
     "emr",
     "emr-containers",
     "emr-serverless",
+    "entityresolution",
     "es",
     "events",
     "evidently",
@@ -310,6 +329,7 @@ ServiceName = Literal[
     "macie",
     "macie2",
     "managedblockchain",
+    "managedblockchain-query",
     "marketplace-catalog",
     "marketplace-entitlement",
     "marketplacecommerceanalytics",
@@ -318,9 +338,11 @@ ServiceName = Literal[
     "medialive",
     "mediapackage",
     "mediapackage-vod",
+    "mediapackagev2",
     "mediastore",
     "mediastore-data",
     "mediatailor",
+    "medical-imaging",
     "memorydb",
     "meteringmarketplace",
     "mgh",
@@ -344,8 +366,11 @@ ServiceName = Literal[
     "opsworks",
     "opsworkscm",
     "organizations",
+    "osis",
     "outposts",
     "panorama",
+    "payment-cryptography",
+    "payment-cryptography-data",
     "personalize",
     "personalize-events",
     "personalize-runtime",
@@ -437,7 +462,9 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "verifiedpermissions",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
